#!/bin/env bash
#
# Configures Chia and Plotman, then launches Machinaris web server
#

echo 'Configuring Chia...'
sed -i 's/log_stdout: true/log_stdout: false/g' /root/.chia/mainnet/config/config.yaml
sed -i 's/log_level: WARNING/log_level: INFO/g' /root/.chia/mainnet/config/config.yaml

echo 'Configuring Plotman...'
mkdir -p /root/.chia/plotman/logs
# Temporarily migrate users with original plotman logs path
if [ -f /root/.chia/plotman/plotman.yaml ]; then
    sed -i 's/\/root\/.chia\/logs/\/root\/.chia\/plotman\/logs/g' /root/.chia/plotman/plotman.yaml
fi
cp -n /machinaris/config/plotman.sample.yaml /root/.chia/plotman/plotman.yaml
if [ ${farmer_pk} != 'null' ]; then
    sed -i "s/^.*farmer_pk:.*$/        farmer_pk: ${farmer_pk}/g" /root/.chia/plotman/plotman.yaml
fi
if [ ${pool_pk} != 'null' ]; then
    sed -i "s/^.*pool_pk:.*$/        pool_pk: ${pool_pk}/g" /root/.chia/plotman/plotman.yaml
fi

if [ "${mode}" != "plotter" ]; then
    echo 'Configuring Chiadog...'
    mkdir -p /root/.chia/chiadog/logs
    cp -n /machinaris/config/chiadog.sample.yaml /root/.chia/chiadog/config.yaml
    cp -f /machinaris/scripts/chiadog_notifier.sh /root/.chia/chiadog/notifier.sh && chmod 755 /root/.chia/chiadog/notifier.sh
    . /machinaris/scripts/setup_databases.sh

    echo 'Starting Chiadog...'
    cd /chiadog
    pidof python3
    if [ $? != 0 ]; then
        python3 -u main.py --config /root/.chia/chiadog/config.yaml > /root/.chia/chiadog/logs/chiadog.log 2>&1 &
    fi
fi

echo 'Starting Machinaris...'
mkdir -p /root/.chia/machinaris/logs
cd /machinaris
if [ $FLASK_ENV == "development" ];
then
    LOG_LEVEL='debug'
    RELOAD='--reload'
else
    LOG_LEVEL='info'
    RELOAD=''
fi

# Kill gunicorn if already running to allow restart
webui_pid=$(pidof 'gunicorn: master [app:app]')
if [ ! -z $webui_pid ]; then 
    kill $webui_pid
fi
/chia-blockchain/venv/bin/gunicorn ${RELOAD} --bind 0.0.0.0:8926 --timeout 90 --log-level=${LOG_LEVEL} app:app > /root/.chia/machinaris/logs/webui.log 2>&1 &
echo 'Completed startup.  Browse to port 8926.'
